[glib/gvariant-utils] small tweak
- From: Ryan Lortie <ryanl src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [glib/gvariant-utils] small tweak
- Date: Fri, 12 Feb 2010 16:14:12 +0000 (UTC)
commit 996c3751dc26aeb3b63a632c08942b1c1c53e48e
Author: Ryan Lortie <desrt desrt ca>
Date: Fri Feb 12 11:13:59 2010 -0500
small tweak
glib/gvariant.c | 8 ++++----
1 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/glib/gvariant.c b/glib/gvariant.c
index eb49c81..14fd0b4 100644
--- a/glib/gvariant.c
+++ b/glib/gvariant.c
@@ -616,8 +616,8 @@ g_variant_is_container (GVariant *value)
/**
* g_variant_new_maybe:
* @type: the #GVariantType of the child
* @value: the child value, or %NULL
* @returns: a new #GVariant maybe instance
*
* Depending on if @value is %NULL, either wraps @value inside of a
@@ -628,8 +628,8 @@ g_variant_is_container (GVariant *value)
* non-%NULL then @type must be the type of @value.
**/
GVariant *
-g_variant_new_maybe (const GVariantType *type,
- GVariant *value)
+g_variant_new_maybe (const GVariantType *child_type,
+ GVariant *child)
{
GVariantType *maybe_type;
[
@@ -616,8 +616,8 @@ g_variant_is_container (GVariant *value)
/**
* g_variant_new_maybe:
- * @type: the #GVariantType of the child
- * @value: the child value, or %NULL
+ * @child_type: the #GVariantType of the child
+ * @child: the child value, or %NULL
* @returns: a new #GVariant maybe instance
*
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]